Learn R Programming

inbreedR (version 0.3.1)

r2_hf: Expected r2 between standardized multilocus heterozygosity (h) and inbreeding level (f)

Description

Expected r2 between standardized multilocus heterozygosity (h) and inbreeding level (f)

Usage

r2_hf(genotypes, type = c("msats", "snps"), nboot = NULL, parallel = FALSE, ncores = NULL, CI = 0.95)

Arguments

genotypes
data.frame with individuals in rows and loci in columns, containing genotypes coded as 0 (homozygote), 1 (heterozygote) and NA (missing)
type
specifies g2 formula to take. Type "snps" for large datasets and "msats" for smaller datasets.
nboot
number of bootstraps over individuals to estimate a confidence interval around r2(h, f)
parallel
Default is FALSE. If TRUE, bootstrapping and permutation tests are parallelized
ncores
Specify number of cores to use for parallelization. By default, all available cores but one are used.
CI
confidence interval (default to 0.95)

Value

call
function call.
r2_hf_full
expected r2 between inbreeding and sMLH for the full dataset
r2_hf_boot
expected r2 values from bootstrapping over individuals
CI_boot
confidence interval around the expected r2
nobs
number of observations
nloc
number of markers

References

Slate, J., David, P., Dodds, K. G., Veenvliet, B. A., Glass, B. C., Broad, T. E., & McEwan, J. C. (2004). Understanding the relationship between the inbreeding coefficient and multilocus heterozygosity: theoretical expectations and empirical data. Heredity, 93(3), 255-265.

Szulkin, M., Bierne, N., & David, P. (2010). HETEROZYGOSITY-FITNESS CORRELATIONS: A TIME FOR REAPPRAISAL. Evolution, 64(5), 1202-1217.

Examples

Run this code
data(mouse_msats)
genotypes <- convert_raw(mouse_msats)
(out <- r2_hf(genotypes, nboot = 100, type = "msats", parallel = FALSE))
plot(out)

Run the code above in your browser using DataLab